@@ -4,7 +4,7 @@
 	 * Russian KOI8 language file for phpPgAdmin. 
 	 * @maintainer Alexander Khodorivsky [askh@ukr.net]
 	 *
-	 * $Id: russian.php,v 1.8 2004/05/31 01:26:14 chriskl Exp $
+	 * $Id: russian.php,v 1.12 2007/04/24 11:42:07 soranzo Exp $
 	 */
 
 	// Language and character set
@@ -12,6 +12,7 @@
 	$lang['appcharset'] = 'KOI8-R';
 	$lang['applocale'] = 'ru_RU';
   	$lang['appdbencoding'] = 'KOI8';
+	$lang['applangdir'] = 'ltr';
 
 	// Welcome  
 	$lang['strintro'] = '&#1044;&#1086;&#1073;&#1088;&#1086; &#1087;&#1086;&#1078;&#1072;&#1083;&#1086;&#1074;&#1072;&#1090;&#1100; &#1074; phpPgAdmin.';
@@ -86,7 +87,7 @@
 	$lang['stradmin'] = '&#1059;&#1087;&#1088;&#1072;&#1074;&#1083;&#1077;&#1085;&#1080;&#1077;';
 	$lang['strvacuum'] = '&#1055;&#1077;&#1088;&#1077;&#1089;&#1090;&#1088;&#1086;&#1080;&#1090;&#1100;';
 	$lang['stranalyze'] = '&#1040;&#1085;&#1072;&#1083;&#1080;&#1079;&#1080;&#1088;&#1086;&#1074;&#1072;&#1090;&#1100;';
-	$lang['strcluster'] = '&#1050;&#1083;&#1072;&#1089;&#1090;&#1077;&#1088;&#1080;&#1079;&#1086;&#1074;&#1072;&#1090;&#1100;';
+	$lang['strclusterindex'] = '&#1050;&#1083;&#1072;&#1089;&#1090;&#1077;&#1088;&#1080;&#1079;&#1086;&#1074;&#1072;&#1090;&#1100;';
 	$lang['strclustered'] = '&#1050;&#1083;&#1072;&#1089;&#1090;&#1077;&#1088;&#1080;&#1079;&#1086;&#1074;&#1072;&#1085;?';
 	$lang['strreindex'] = '&#1055;&#1077;&#1088;&#1077;&#1089;&#1090;&#1088;&#1086;&#1080;&#1090;&#1100; &#1080;&#1085;&#1076;&#1077;&#1082;&#1089;';
 	$lang['strrun'] = '&#1042;&#1099;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1100;';
@@ -125,7 +126,6 @@
 	$lang['strfileimported'] = '&#1060;&#1072;&#1081;&#1083; &#1080;&#1084;&#1087;&#1086;&#1088;&#1090;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;.';
 
 	// Error handling
-	$lang['strnoframes'] = '&#1044;&#1083;&#1103; &#1080;&#1089;&#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1085;&#1080;&#1103; &#1076;&#1072;&#1085;&#1085;&#1086;&#1075;&#1086; &#1087;&#1088;&#1080;&#1083;&#1086;&#1078;&#1077;&#1085;&#1080;&#1103; &#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1080;&#1084;&#1077;&#1090;&#1100; &#1073;&#1088;&#1072;&#1091;&#1079;&#1077;&#1088;, &#1087;&#1086;&#1076;&#1076;&#1077;&#1088;&#1078;&#1080;&#1074;&#1072;&#1102;&#1097;&#1080;&#1081; &#1092;&#1088;&#1077;&#1081;&#1084;&#1099;.';
 	$lang['strbadconfig'] = '&#1042;&#1072;&#1096; config.inc.php &#1103;&#1074;&#1083;&#1103;&#1077;&#1090;&#1089;&#1103; &#1091;&#1089;&#1090;&#1072;&#1088;&#1077;&#1074;&#1096;&#1080;&#1084;. &#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1086;&#1073;&#1085;&#1086;&#1074;&#1080;&#1090;&#1100; &#1077;&#1075;&#1086; &#1080;&#1079; config.inc.php-dist.';
 	$lang['strnotloaded'] = '&#1042;&#1072;&#1096;&#1072; &#1080;&#1085;&#1089;&#1090;&#1072;&#1083;&#1103;&#1094;&#1080;&#1103; PHP &#1085;&#1077; &#1087;&#1086;&#1076;&#1076;&#1077;&#1088;&#1078;&#1080;&#1074;&#1072;&#1077;&#1090; PostgreSQL. &#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1087;&#1077;&#1088;&#1077;&#1089;&#1086;&#1073;&#1088;&#1072;&#1090;&#1100; PHP, &#1080;&#1089;&#1087;&#1086;&#1083;&#1100;&#1079;&#1091;&#1103; &#1087;&#1072;&#1088;&#1072;&#1084;&#1077;&#1090;&#1088; --with-pgsql &#1076;&#1083;&#1103; configure.';
 	$lang['strbadschema'] = '&#1054;&#1073;&#1085;&#1072;&#1088;&#1091;&#1078;&#1077;&#1085;&#1072; &#1085;&#1077;&#1074;&#1077;&#1088;&#1085;&#1072;&#1103; &#1089;&#1093;&#1077;&#1084;&#1072;.';
@@ -322,7 +322,6 @@
 	$lang['strcachevalue'] = '&#1056;&#1072;&#1079;&#1084;&#1077;&#1088; &#1082;&#1101;&#1096;&#1072;';
 	$lang['strlogcount'] = 'Log Count';
 	$lang['striscycled'] = '&#1047;&#1072;&#1094;&#1080;&#1082;&#1083;&#1080;&#1090;&#1100;?';
-	$lang['striscalled'] = '&#1059;&#1078;&#1077; &#1074;&#1099;&#1079;&#1099;&#1074;&#1072;&#1083;&#1072;&#1089;&#1100;?';
 	$lang['strsequenceneedsname'] = '&#1042;&#1072;&#1084; &#1085;&#1077;&#1086;&#1073;&#1093;&#1086;&#1076;&#1080;&#1084;&#1086; &#1091;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1080;&#1084;&#1103; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080;.';
 	$lang['strsequencecreated'] = '&#1055;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1100; &#1089;&#1086;&#1079;&#1076;&#1072;&#1085;&#1072;.';
 	$lang['strsequencecreatedbad'] = '&#1057;&#1086;&#1079;&#1076;&#1072;&#1085;&#1080;&#1077; &#1087;&#1086;&#1089;&#1083;&#1077;&#1076;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100;&#1085;&#1086;&#1089;&#1090;&#1080; &#1087;&#1088;&#1077;&#1088;&#1074;&#1072;&#1085;&#1086;.';
@@ -595,7 +594,7 @@
 	$lang['strrows2'] = '&#1047;&#1072;&#1087;&#1080;&#1089;&#1080;';
 
 	// Miscellaneous
-	$lang['strtopbar'] = '%s &#1074;&#1099;&#1087;&#1086;&#1083;&#1085;&#1103;&#1077;&#1090;&#1089;&#1103; &#1085;&#1072; %s:%s -- &#1042;&#1099; &#1079;&#1072;&#1088;&#1077;&#1075;&#1080;&#1089;&#1090;&#1088;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;&#1099; &#1082;&#1072;&#1082; &quot;%s&quot;, %s';
+	$lang['strtopbar'] = '%s &#1074;&#1099;&#1087;&#1086;&#1083;&#1085;&#1103;&#1077;&#1090;&#1089;&#1103; &#1085;&#1072; %s:%s -- &#1042;&#1099; &#1079;&#1072;&#1088;&#1077;&#1075;&#1080;&#1089;&#1090;&#1088;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;&#1099; &#1082;&#1072;&#1082; &quot;%s&quot;';
 	$lang['strtimefmt'] = ' j-m-Y  g:i';
 	$lang['strhelp'] = '&#1055;&#1086;&#1084;&#1086;&#1097;&#1100;';
 
