@@ -3,7 +3,7 @@
 	* Romanian language file, based on the english language file for phpPgAdmin.
 	* Alin Vaida [alin.vaida@gmail.com]
 	*
-	* $Id: romanian.php,v 1.1.2.1 2004/12/02 02:28:54 chriskl Exp $
+	* $Id: romanian.php,v 1.7 2007/04/24 11:42:07 soranzo Exp $
 	*/
 
 	// Language and character set
@@ -28,6 +28,10 @@
 	$lang['strloginfailed'] = 'Autentificare eşuată';
 	$lang['strlogindisallowed'] = 'Autentificare nepermisă din motive de securitate.';
 	$lang['strserver'] = 'Server';
+	$lang['strservers'] = 'Servere';
+	$lang['strintroduction'] = 'Introducere';
+	$lang['strhost'] = 'Gazdă';
+	$lang['strport'] = 'Port';
 	$lang['strlogout'] = 'Ieşire';
 	$lang['strowner'] = 'Proprietar';
 	$lang['straction'] = 'Acţiune';
@@ -36,6 +40,8 @@
 	$lang['strdefinition'] = 'Definiţie';
 	$lang['strproperties'] = 'Proprietăţi';
 	$lang['strbrowse'] = 'Vizualizare';
+	$lang['strenable'] = 'Activare';
+	$lang['strdisable'] = 'Dezactivare';
 	$lang['strdrop'] = 'Ştergere';
 	$lang['strdropped'] = 'Şters';
 	$lang['strnull'] = 'Nul';
@@ -53,6 +59,7 @@
 	$lang['stralter'] = 'Modificare';
 	$lang['strok'] = 'OK';
 	$lang['strcancel'] = 'Anulare';
+	$lang['strac'] = 'Activare Auto-completare';
 	$lang['strsave'] = 'Salvare';
 	$lang['strreset'] = 'Reiniţializare';
 	$lang['strinsert'] = 'Inserare';
@@ -70,7 +77,6 @@
 	$lang['strrows'] = 'rând(uri)';
 	$lang['strrowsaff'] = 'rând(uri) afectate.';
 	$lang['strobjects'] = 'obiect(e)';
-	$lang['strexample'] = 'ex.';
 	$lang['strback'] = 'Înapoi';
 	$lang['strqueryresults'] = 'Rezultatele interogării';
 	$lang['strshow'] = 'Afişare';
@@ -82,19 +88,21 @@
 	$lang['strprimary'] = 'Primar';
 	$lang['strexport'] = 'Export';
 	$lang['strimport'] = 'Import';
+	$lang['strallowednulls'] = 'Caractere NULL permise';
+	$lang['strbackslashn'] = '\N';
+	$lang['stremptystring'] = 'Şir/câmp gol';
 	$lang['strsql'] = 'SQL';
-	$lang['strgo'] = 'Executare';
 	$lang['stradmin'] = 'Administrare';
 	$lang['strvacuum'] = 'Vacuum';
 	$lang['stranalyze'] = 'Analiză';
-	$lang['strcluster'] = 'Grupare';
+	$lang['strclusterindex'] = 'Grupare';
 	$lang['strclustered'] = 'Grupat?';
 	$lang['strreindex'] = 'Re-indexare';
 	$lang['strrun'] = 'Executare';
 	$lang['stradd'] = 'Adăugare';
 	$lang['strevent'] = 'Eveniment';
-	$lang['strwhere'] = 'Condiţie';
 	$lang['strwhere'] = 'În schimb';
+	$lang['strinstead'] = 'Execută în schimb';
 	$lang['strwhen'] = 'Când';
 	$lang['strformat'] = 'Format';
 	$lang['strdata'] = 'Dată';
@@ -125,12 +133,21 @@
 	$lang['strstarttime'] = 'Timp start';
 	$lang['strfile'] = 'Fişier';
 	$lang['strfileimported'] = 'Fişier importat';
+	$lang['strtrycred'] = 'Folosiţi aceste acreditări pentru toate serverele';
+
+	// Database sizes
+	$lang['strsize'] = 'Dimensiune';
+	$lang['strbytes'] = 'octeţi';
+	$lang['strkb'] = 'kB';
+	$lang['strmb'] = 'MB';
+	$lang['strgb'] = 'GB';
+	$lang['strtb'] = 'TB';
 
 	// Error handling
-	$lang['strnoframes'] = 'Aveţi nevoie de un browser capabil să afişeze frame-uri pentru a utiliza această aplicaţie.';
-	$lang['strbadconfig'] = 'Fişierul config.inc.php este învechit. Trebuie să-l re-generaţi folosind fişierul config.inc.php-dist.';
+	$lang['strnoframes'] = 'Această aplicaţie funcţionează cel mai bine într-un browser ce suportă frame-uri , dar poate fi folosită şi fără frame-uri, urmând legătura de mai jos.';
+	$lang['strnoframeslink'] = 'Fără frame-uri';
+	$lang['strbadconfig'] = 'Fişierul config.inc.php este învechit. Trebuie să-l re-generaţi folosind noul fişier config.inc.php-dist.';
 	$lang['strnotloaded'] = 'Instalarea de PHP nu suportă PostgreSQL. Trebuie să re-compilaţi PHP folosind opţiunea --with-pgsql la configurare.';
-	$lang['strphpversionnotsupported'] = 'Versiune de PHP ne-suportată. Actualizaţi la versiunea %s sau ulterioară.';
 	$lang['strpostgresqlversionnotsupported'] = 'Versiune de PostgreSQL ne-suportată. Actualizaţi la versiunea %s sau ulterioară.';
 	$lang['strbadschema'] = 'Schemă specificată incorectă.';
 	$lang['strbadencoding'] = 'Imposibil de setat codificarea client în baza de date.';
@@ -143,7 +160,11 @@
 	$lang['strnoreportsdb'] = 'Nu aţi creat baza de date pentru rapoarte. Citiţi fişierul INSTALL pentru instrucţiuni.';
 	$lang['strnouploads'] = 'Încărcarea de fişiere este dezactivată.';
 	$lang['strimporterror'] = 'Eroare la importare.';
+	$lang['strimporterror-fileformat'] = 'Eroare la importare: Imposibil de determinat în mod automat formatul fişierului.';
 	$lang['strimporterrorline'] = 'Eroare la importare pe linia %s.';
+	$lang['strimporterrorline-badcolumnnum'] = 'Eroare la importare pe linia %s:  Linia nu are numărul corect de coloane.';
+	$lang['strimporterror-uploadedfile'] = 'Eroare la importare: Fişierul nu a putut fi încărcat pe server';
+	$lang['strcannotdumponwindows'] = 'Descărcarea de tabele complexe şi nume de scheme în Windows nu este suportată.';
 
 	// Tables
 	$lang['strtable'] = 'Tabelă';
@@ -167,6 +188,7 @@
 	$lang['strinsertrow'] = 'Inserare rând';
 	$lang['strrowinserted'] = 'Rând inserat';
 	$lang['strrowinsertedbad'] = 'Inserare rând eşuată.';
+	$lang['strrowduplicate'] = 'Inserare de rând eşuată, s-a încercat inserarea unui duplicat.';
 	$lang['streditrow'] = 'Editare rând';
 	$lang['strrowupdated'] = 'Rând actualizat.';
 	$lang['strrowupdatedbad'] = 'Actualizare rând eşuată.';
@@ -200,6 +222,9 @@
 	$lang['strconfvacuumtable'] = 'Sigur executaţi "vacuum" pe "%s"?';
 	$lang['strestimatedrowcount'] = 'Număr estimat de rânduri';
 
+	// Columns
+	$lang['strcolprop'] = 'Proprietăţi coloană';
+
 	// Users
 	$lang['struser'] = 'Utilizator';
 	$lang['strusers'] = 'Utilizatori';
@@ -230,10 +255,10 @@
 	// Groups
 	$lang['strgroup'] = 'Grup';
 	$lang['strgroups'] = 'Grupuri';
+	$lang['strshowallgroups'] = 'Afişare toate grupurile';
 	$lang['strnogroup'] = 'Grup negăsit.';
 	$lang['strnogroups'] = 'Nici un grup găsit.';
 	$lang['strcreategroup'] = 'Creare grup';
-	$lang['strshowallgroups'] = 'Afişare toate grupurile';
 	$lang['strgroupneedsname'] = 'Specificaţi un nume pentru grup.';
 	$lang['strgroupcreated'] = 'Grup creat.';
 	$lang['strgroupcreatedbad'] = 'Creare grup eşuată.';
@@ -241,6 +266,8 @@
 	$lang['strgroupdropped'] = 'Grup şters.';
 	$lang['strgroupdroppedbad'] = 'Ştergere grup eşuată.';
 	$lang['strmembers'] = 'Membri';
+	$lang['strmemberof'] = 'Membru al';
+	$lang['stradminmembers'] = 'Membri administratori';
 	$lang['straddmember'] = 'Adăugare membru';
 	$lang['strmemberadded'] = 'Membru adăugat.';
 	$lang['strmemberaddedbad'] = 'Adăugare membru eşuată.';
@@ -249,6 +276,29 @@
 	$lang['strmemberdropped'] = 'Membru şters.';
 	$lang['strmemberdroppedbad'] = 'Ştergere membru eşuată.';
 
+	// Roles
+	$lang['strrole'] = 'Rol';
+	$lang['strroles'] = 'Roluri';
+	$lang['strshowallroles'] = 'Afişare toate rolurile';
+	$lang['strnoroles'] = 'Nici un rol găsit';
+	$lang['strinheritsprivs'] = 'Moştenire privilegii?';
+	$lang['strcreaterole'] = 'Creare rol';
+	$lang['strcancreaterole'] = 'Creare rol posibilă?';
+	$lang['strrolecreated'] = 'Rol creat';
+	$lang['strrolecreatedbad'] = 'Creare rol eşuată';
+	$lang['stralterrole'] = 'Modificare rol';
+	$lang['strrolealtered'] = 'Rol modificat';
+	$lang['strrolealteredbad'] = 'Modificare rol eşuată';
+	$lang['strcanlogin'] = 'Autentificare posibilă?';
+	$lang['strconnlimit'] = 'Limită conectare';
+	$lang['strdroprole'] = 'Ştergere rol';
+	$lang['strconfdroprole'] = 'Sigur ştergeţi rolul "%s"?';
+	$lang['strroledropped'] = 'Rol şters';
+	$lang['strroledroppedbad'] = 'Ştergere rol eşuată';
+	$lang['strnolimit'] = 'Fără limită';
+	$lang['strnever'] = 'Niciodată';
+	$lang['strroleneedsname'] = 'Specificaţi un nume pentru rol';
+
 	// Privileges
 	$lang['strprivilege'] = 'Privilegiu';
 	$lang['strprivileges'] = 'Privilegii';
@@ -265,7 +315,6 @@
 	$lang['strdatabase'] = 'Bază de date';
 	$lang['strdatabases'] = 'Baze de date';
 	$lang['strshowalldatabases'] = 'Afişare toate bazele de date';
-	$lang['strnodatabase'] = 'Nici o bază de date găsită.';
 	$lang['strnodatabases'] = 'Nici o bază de date găsită.';
 	$lang['strcreatedatabase'] = 'Creare bază de date';
 	$lang['strdatabasename'] = 'Nume bază de date';
@@ -289,6 +338,8 @@
 	$lang['strsignalsent'] = 'Semnal trimis.';
 	$lang['strsignalsentbad'] = 'Trimitere semnal eşuată.';
 	$lang['strallobjects'] = 'Toate obiectele';
+	$lang['strdatabasealtered'] = 'Bază de date modificată.';
+	$lang['strdatabasealteredbad'] = 'Modificarea bazei de date a eşuat.';
 
 	// Views
 	$lang['strview'] = 'Vizualizare';
@@ -327,7 +378,6 @@
 	$lang['strcachevalue'] = 'Valoare cache';
 	$lang['strlogcount'] = 'Log count';
 	$lang['striscycled'] = 'Ciclică?';
-	$lang['striscalled'] = 'Apelată?';
 	$lang['strsequenceneedsname'] = 'Specificaţi un nume pentru secvenţă.';
 	$lang['strsequencecreated'] = 'Secvenţă creată.';
 	$lang['strsequencecreatedbad'] = 'Creare secvenţă eşuată.';
@@ -336,6 +386,15 @@
 	$lang['strsequencedroppedbad'] = 'Ştergere secvenţă eşuată.';
 	$lang['strsequencereset'] = 'Reiniţializare secvenţă.';
 	$lang['strsequenceresetbad'] = 'Reiniţializare secvenţă eşuată.';
+	$lang['straltersequence'] = 'Modificare secvenţă';
+	$lang['strsequencealtered'] = 'Secvenţă modificată';
+	$lang['strsequencealteredbad'] = 'Modificare secvenţă eşuată';
+	$lang['strsetval'] = 'Setare valoare';
+	$lang['strsequencesetval'] = 'Valoare secvenţă setată';
+	$lang['strsequencesetvalbad'] = 'Setare valoare secvenţă eşuată';
+	$lang['strnextval'] = 'Valoare increment';
+	$lang['strsequencenextval'] = 'Secvenţă incrementată';
+	$lang['strsequencenextvalbad'] = 'Incremetare secvenţă eşuată';
 
 	// Indexes
 	$lang['strindex'] = 'Index';
@@ -380,6 +439,7 @@
 	$lang['strruledroppedbad'] = 'Ştergere regulă eşuată.';
 
 	// Constraints
+	$lang['strconstraint'] = 'Restricţie';
 	$lang['strconstraints'] = 'Restricţii';
 	$lang['strshowallconstraints'] = 'Afişare toate restricţiile';
 	$lang['strnoconstraints'] = 'Nici o restricţie găsită.';
@@ -422,7 +482,6 @@
 	$lang['strcreatecfunction'] = 'Creare funcţie C';
 	$lang['strfunctionname'] = 'Nume funcţie';
 	$lang['strreturns'] = 'Întoarce';
-	$lang['strarguments'] = 'Argumente';
 	$lang['strproglanguage'] = 'Limbaj de programare';
 	$lang['strfunctionneedsname'] = 'Specificaţi un nume pentru funcţie.';
 	$lang['strfunctionneedsdef'] = 'Specificaţi o definiţie pentru functie.';
@@ -435,6 +494,18 @@
 	$lang['strfunctionupdatedbad'] = 'Actualizare funcţie eşuată.';
 	$lang['strobjectfile'] = 'Fişier obiect';
 	$lang['strlinksymbol'] = 'Simbol de legătură';
+	$lang['strarguments'] = 'Argumente';
+	$lang['strargmode'] = 'Mod';
+	$lang['strargtype'] = 'Tip';
+	$lang['strargadd'] = 'Adăugare alt argument';
+	$lang['strargremove'] = 'Eliminare argument';
+	$lang['strargnoargs'] = 'Această funcţie nu acceptă nici un argument';
+	$lang['strargenableargs'] = 'Activare argumente pasate acestei funcţii';
+	$lang['strargnorowabove'] = 'Trebuie să existe un rând deasupra acestui rând';
+	$lang['strargnorowbelow'] = 'Trebuie să existe un rând dedesubtul acestui rând';
+	$lang['strargraise'] = 'Mutare în sus';
+	$lang['strarglower'] = 'Mutare în jos';
+	$lang['strargremoveconfirm'] = 'Sigur eliminaţi acest argument? Această acţiune NU poate fi revocată.';
 
 	// Triggers
 	$lang['strtrigger'] = 'Declanşator';
@@ -448,10 +519,17 @@
 	$lang['strtriggercreated'] = 'Declanşator creat.';
 	$lang['strtriggercreatedbad'] = 'Creare declanşator eşuată.';
 	$lang['strconfdroptrigger'] = 'Sigur ştergeţi declanşatorul "%s" de pe "%s"?';
+	$lang['strconfenabletrigger'] = 'Sigur activaţi declanşatorul "%s" pentru "%s"?';
+	$lang['strconfdisabletrigger'] = 'Sigur dezactivaţi declanşatorul "%s" pentru "%s"?';
 	$lang['strtriggerdropped'] = 'Declanşator şters.';
 	$lang['strtriggerdroppedbad'] = 'Ştergere declanşator eşuată.';
+	$lang['strtriggerenabled'] = 'Declanşator activat';
+	$lang['strtriggerenabledbad'] = 'Activare declanşator eşuată';
+	$lang['strtriggerdisabled'] = 'Declanşator dezactivat';
+	$lang['strtriggerdisabledbad'] = 'Dezactivare declanşator eşuată';
 	$lang['strtriggeraltered'] = 'Declanşator modificat.';
 	$lang['strtriggeralteredbad'] = 'Modificare declanşator eşuată.';
+	$lang['strforeach'] = 'Pentru fiecare';
 
 	// Types
 	$lang['strtype'] = 'Tip';
@@ -585,9 +663,31 @@
 	$lang['strchildtables'] = 'Tabele copii';
 
 	// Aggregates
+	$lang['straggregate'] = 'Agregare';
 	$lang['straggregates'] = 'Agregări';
 	$lang['strnoaggregates'] = 'Nici o agregare găsită.';
 	$lang['stralltypes'] = '(Toate tipurile)';
+	$lang['straggrtransfn'] = 'Funcţie de tranziţie';
+	$lang['strcreateaggregate'] = 'Creare agregare';
+	$lang['straggrbasetype'] = 'Tip dată de intrare';
+	$lang['straggrsfunc'] = 'Funcţie tranziţie de stare';
+	$lang['straggrffunc'] = 'Funcţie finală';
+	$lang['straggrinitcond'] = 'Condiţie iniţială';
+	$lang['straggrsortop'] = 'Operator sortare';
+	$lang['strdropaggregate'] = 'Ştergere agregare';
+	$lang['strconfdropaggregate'] = 'Sigur ştergeţi agregarea "%s"?';
+	$lang['straggregatedropped'] = 'Agregare ştearsă.';
+	$lang['straggregatedroppedbad'] = 'Ştergere agregare eşuată.';
+	$lang['stralteraggregate'] = 'Modificare agregare';
+	$lang['straggraltered'] = 'Agregare modificată.';
+	$lang['straggralteredbad'] = 'Modificare agregare eşuată.';
+	$lang['straggrneedsname'] = 'Specificaţi un nume pentru agregare';
+	$lang['straggrneedsbasetype'] = 'Specificaţi tipul de dată de intrare pentru agregare';
+	$lang['straggrneedssfunc'] = 'Specificaţi numele funcţiei tranziţiei de stare pentru agregare';
+	$lang['straggrneedsstype'] = 'Specificaţi tipul datei pentru valoarea stării agregării';
+	$lang['straggrcreated'] = 'Agregare creată.';
+	$lang['straggrcreatedbad'] = 'Creare agregare eşuată.';
+	$lang['straggrshowall'] = 'Afişare toate agregările';
 
 	// Operator Classes
 	$lang['stropclasses'] = 'Clase de operatori';
@@ -628,11 +728,156 @@
 	$lang['strtablespacealtered'] = 'Spaţiu de tabele modificat.';
 	$lang['strtablespacealteredbad'] = 'Modificare şpaţiu de tabele eşuată.';
 
+	// Slony clusters
+	$lang['strcluster'] = 'Grupare';
+	$lang['strnoclusters'] = 'Nici o grupare găsită.';
+	$lang['strconfdropcluster'] = 'Sigur ştergeţi gruparea "%s"?';
+	$lang['strclusterdropped'] = 'Grupare ştearsă.';
+	$lang['strclusterdroppedbad'] = 'Ştergere grupare eşuată.';
+	$lang['strinitcluster'] = 'Iniţializare grupare';
+	$lang['strclustercreated'] = 'Grupare iniţializată.';
+	$lang['strclustercreatedbad'] = 'Iniţializare grupare eşuată.';
+	$lang['strclusterneedsname'] = 'Trebuie să daţi un nume grupării.';
+	$lang['strclusterneedsnodeid'] = 'Trebuie să daţi un identificator nodului local.';
+
+	// Slony nodes
+	$lang['strnodes'] = 'Noduri';
+	$lang['strnonodes'] = 'Nici un nod găsit.';
+	$lang['strcreatenode'] = 'Creare nod';
+	$lang['strid'] = 'ID';
+	$lang['stractive'] = 'Activ(ă)';
+	$lang['strnodecreated'] = 'Nod creat.';
+	$lang['strnodecreatedbad'] = 'Creare nod eşuată.';
+	$lang['strconfdropnode'] = 'Sigur ştergeţi nodul "%s"?';
+	$lang['strnodedropped'] = 'Nod şters.';
+	$lang['strnodedroppedbad'] = 'Ştergere nod eşuată';
+	$lang['strfailover'] = 'Failover';
+	$lang['strnodefailedover'] = 'Node failed over.';
+	$lang['strnodefailedoverbad'] = 'Node failover failed.';
+	$lang['strstatus'] = 'Stare';
+	$lang['strhealthy'] = 'Intact';
+	$lang['stroutofsync'] = 'Desincronizat';
+	$lang['strunknown'] = 'Necunoscut';
+
+	// Slony paths
+	$lang['strpaths'] = 'Căi';
+	$lang['strnopaths'] = 'Nici o cale găsită.';
+	$lang['strcreatepath'] = 'Creare cale';
+	$lang['strnodename'] = 'Nume nod';
+	$lang['strnodeid'] = 'ID nod';
+	$lang['strconninfo'] = 'Şir pentru conectare';
+	$lang['strconnretry'] = 'Secunde până la o nouă încercare de conectare';
+	$lang['strpathneedsconninfo'] = 'Trebuie să daţi un şir de conectare pentru cale.';
+	$lang['strpathneedsconnretry'] = 'Trebuie să daţi numărul de secunde până la o nouă încercare de conectare.';
+	$lang['strpathcreated'] = 'Cale creată.';
+	$lang['strpathcreatedbad'] = 'Creare cale eşuată.';
+	$lang['strconfdroppath'] = 'Sigur ştergeţi calea "%s"?';
+	$lang['strpathdropped'] = 'Cale ştearsă.';
+	$lang['strpathdroppedbad'] = 'Ştergere cale eşuată.';
+
+	// Slony listens
+	$lang['strlistens'] = 'Ascultări';
+	$lang['strnolistens'] = 'Nici o ascultare găsită.';
+	$lang['strcreatelisten'] = 'Creare ascultare';
+	$lang['strlistencreated'] = 'Ascultare creată.';
+	$lang['strlistencreatedbad'] = 'Creare ascultare eşuată.';
+	$lang['strconfdroplisten'] = 'Sigur ştergeţi ascultarea "%s"?';
+	$lang['strlistendropped'] = 'Ascultare ştearsă.';
+	$lang['strlistendroppedbad'] = 'Ştergere ascultare eşuată.';
+
+	// Slony replication sets
+	$lang['strrepsets'] = 'Seturi de replicare';
+	$lang['strnorepsets'] = 'Nici un set de replicare găsit.';
+	$lang['strcreaterepset'] = 'Creare set de replicare';
+	$lang['strrepsetcreated'] = 'Set de replicare creat';
+	$lang['strrepsetcreatedbad'] = 'Creare set de replicare eşuată';
+	$lang['strconfdroprepset'] = 'Sigur ştergeţi setul de replicare "%s"?';
+	$lang['strrepsetdropped'] = 'Set de replicare şters';
+	$lang['strrepsetdroppedbad'] = 'Ştergere set de replicare eşuată.';
+	$lang['strmerge'] = 'Contopire';
+	$lang['strmergeinto'] = 'Contopire în';
+	$lang['strrepsetmerged'] = 'Seturi de replicare contopite';
+	$lang['strrepsetmergedbad'] = 'Contopire seturi de replicare eşuată.';
+	$lang['strmove'] = 'Mutare';
+	$lang['strneworigin'] = 'Origine nouă';
+	$lang['strrepsetmoved'] = 'Set de replicare mutat';
+	$lang['strrepsetmovedbad'] = 'Mutare set de replicare eşuată.';
+	$lang['strnewrepset'] = 'Set de replicare nou';
+	$lang['strlock'] = 'Blocare';
+	$lang['strlocked'] = 'Blocat';
+	$lang['strunlock'] = 'Deblocare';
+	$lang['strconflockrepset'] = 'Siguri blocaţi setul de replicare "%s"?';
+	$lang['strrepsetlocked'] = 'Set de replicare blocat';
+	$lang['strrepsetlockedbad'] = 'Blocare set de replicare eşuată.';
+	$lang['strconfunlockrepset'] = 'Sigur deblocaţi setul de replicare "%s"?';
+	$lang['strrepsetunlocked'] = 'Set de replicare deblocat';
+	$lang['strrepsetunlockedbad'] = 'Deblocare set de replicare eşuată.';
+	$lang['strexecute'] = 'Executare';
+	$lang['stronlyonnode'] = 'Numai pentru nodul';
+	$lang['strddlscript'] = 'Script DDL';
+	$lang['strscriptneedsbody'] = 'Trebuie să furnizaţi un script care să fie executat pentru toate nodurile.';
+	$lang['strscriptexecuted'] = 'Scriptul DDL pentru setul de replicare a fost executat.';
+	$lang['strscriptexecutedbad'] = 'Executare script DDL pentru setul de replicare eşuată.';
+	$lang['strtabletriggerstoretain'] = 'Următoarele declanşatoare NU vor fi dezactivate de Slony:';
+
+	// Slony tables in replication sets
+	$lang['straddtable'] = 'Adăugare tabelă';
+	$lang['strtableneedsuniquekey'] = 'Tabela adăugată necesită o cheie primară sau unică.';
+	$lang['strtableaddedtorepset'] = 'Tabelă adăugată setului de replicare.';
+	$lang['strtableaddedtorepsetbad'] = 'Adăugare tabelă la setul de replicare eşuată.';
+	$lang['strconfremovetablefromrepset'] = 'Sigur eliminaţi tabela "%s" din setul de replicare "%s"?';
+	$lang['strtableremovedfromrepset'] = 'Tabelă eliminată din setul de replicare.';
+	$lang['strtableremovedfromrepsetbad'] = 'Eliminare tabelă din setul de replicare eşuată.';
+
+	// Slony sequences in replication sets
+	$lang['straddsequence'] = 'Adăugare secvenţă';
+	$lang['strsequenceaddedtorepset'] = 'Secvenţă adăugată setului de replicare.';
+	$lang['strsequenceaddedtorepsetbad'] = 'Adăugare secvenţă la setul de replicare eşuată.';
+	$lang['strconfremovesequencefromrepset'] = 'Sigur eliminaţi secvenţa "%s" din setul de replicare "%s"?';
+	$lang['strsequenceremovedfromrepset'] = 'Secvenţă eliminată din setul de replicare.';
+	$lang['strsequenceremovedfromrepsetbad'] = 'Eliminare secvenţă din setul de replicare eşuată.';
+
+	// Slony subscriptions
+	$lang['strsubscriptions'] = 'Subscriere';
+	$lang['strnosubscriptions'] = 'Nici o subscriere găsită.';
+
 	// Miscellaneous
-	$lang['strtopbar'] = '%s rulând pe %s:%s -- Sunteţi autentificat ca utilizator "%s", %s';
+	$lang['strtopbar'] = '%s rulând pe %s:%s -- Sunteţi autentificat ca utilizator "%s"';
 	$lang['strtimefmt'] = 'jS M, Y g:iA';
 	$lang['strhelp'] = 'Ajutor';
 	$lang['strhelpicon'] = '?';
+	$lang['strhelppagebrowser'] = 'Pagini de ajutor';
+	$lang['strselecthelppage'] = 'Selectaţi o pagină de ajutor';
+	$lang['strinvalidhelppage'] = 'Pagină de ajutor incorectă.';
+	$lang['strlogintitle'] = 'Autentificare la %s';
+	$lang['strlogoutmsg'] = 'Ieşire din %s';
+	$lang['strloading'] = 'Încărcare...';
+	$lang['strerrorloading'] = 'Eroare la încărcare';
+	$lang['strclicktoreload'] = 'Faceţi clic pentru reîncărcare';
+
+	// Autovacuum
+	$lang['strautovacuum'] = 'Autovacuum';
+	$lang['strturnedon'] = 'Pornit';
+	$lang['strturnedoff'] = 'Oprit';
+	$lang['strenabled'] = 'Activat';
+	$lang['strvacuumbasethreshold'] = 'Vacuum Base Threshold';
+	$lang['strvacuumscalefactor'] = 'Vacuum Scale Factor';
+	$lang['stranalybasethreshold'] = 'Analyze Base Threshold';
+	$lang['stranalyzescalefactor'] = 'Analyze Scale Factor';
+	$lang['strvacuumcostdelay'] = 'Vacuum Cost Delay';
+	$lang['strvacuumcostlimit'] = 'Vacuum Cost Limit';
+
+	// Table-level Locks
+	$lang['strlocks'] = 'Blocări';
+	$lang['strtransaction'] = 'ID tranzacţie';
+	$lang['strprocessid'] = 'ID proces';
+	$lang['strmode'] = 'Mod blocare';
+	$lang['strislockheld'] = 'Blocaj reţinut?';
+
+	// Prepared transactions
+	$lang['strpreparedxacts'] = 'Tranzacţii preparate';
+	$lang['strxactid'] = 'ID tranzacţie';
+	$lang['strgid'] = 'ID global';
 
 
 
