@@ -594,7 +594,7 @@
 	$lang['strrows2'] = '';
 
 	// Miscellaneous
-	$lang['strtopbar'] = '%s   %s:%s --    "%s", %s';
+	$lang['strtopbar'] = '%s   %s:%s --    "%s"';
 	$lang['strtimefmt'] = ' j-m-Y  g:i';
 	$lang['strhelp'] = '';
 
