@@ -5,7 +5,7 @@
 	 * maintainer S. Malmqvist <samoola@slak.nu>
 	 * Due to lack of SQL knowledge som translations may be wrong, mail me the correct one and ill fix it
 	 *
-	 * $Id: swedish.php,v 1.7 2004/01/13 00:27:29 chriskl Exp $
+	 * $Id: swedish.php,v 1.11 2007/04/24 11:42:07 soranzo Exp $
 	 */
 
 	// Language and character set
@@ -13,6 +13,7 @@
 	$lang['appcharset'] = 'ISO-8859-1';
 	$lang['applocale'] = 'sv_SE';
 	$lang['appdbencoding'] = 'LATIN1';
+	$lang['applangdir'] = 'ltr';
 
 	// Welcome  
 	$lang['strintro'] = 'Vlkommen till phpPgAdmin.';
@@ -87,7 +88,7 @@
 	$lang['stradmin'] = 'Admin';
 	$lang['strvacuum'] = 'Stda upp';
 	$lang['stranalyze'] = 'Analysera';
-	$lang['strcluster'] = 'Kluster';
+	$lang['strclusterindex'] = 'Kluster';
 	$lang['strclustered'] = 'Klustrat?';
 	$lang['strreindex'] = 'terindexera';
 	$lang['strrun'] = 'Kr';
@@ -119,7 +120,6 @@
 	$lang['strparameters'] = 'Parametrar';
 
 	// Error handling
-	$lang['strnoframes'] = 'Du behver en weblsare som stder frames fr att anvnda detta program.';
 	$lang['strnotloaded'] = 'Du har inte kompilerat in korrekt databasstd i din PHP-installation.';
 	$lang['strbadconfig'] = 'Din config.inc.php r ej uppdaterad. Du mste terskapa den frn den nya config.inc.php-dist.';
 	$lang['strbadencoding'] = 'Misslyckades att stta klientkodning i databasen.';
@@ -224,9 +224,9 @@
 	$lang['strgroupdropped'] = 'Grupp raderad.';
 	$lang['strgroupcreatedbad'] = 'Misslyckades att skapa grupp.';	
 	$lang['strconfdropgroup'] = 'r du sker p att du vill radera grupp "%s"?';
-	$lang['strprivileges'] = 'Privilegier';
+	$lang['strprivileges'] = 'Rttigheter';
 	$lang['strgrant'] = 'Tillt';
-	$lang['strgranted'] = 'Privilegier ndrade.';
+	$lang['strgranted'] = 'Rttigheter ndrade.';
 	$lang['strgroupdroppedbad'] = 'Misslyckades att radera grupp.';
 	$lang['straddmember'] = 'Lgg till medlem';
 	$lang['strmemberadded'] = 'Medlem inlagd.';
@@ -239,7 +239,7 @@
 	$lang['strnoprivileges'] = 'Detta objekt har standard garrttigheter.';
 	$lang['strmembers'] = 'Medelemmar';
 	$lang['strrevoke'] = 'Ta tillbaka';
-	$lang['strgrantbad'] = 'Du mste ange minst en anvndare eller grupp och minst ett privilegium.';
+	$lang['strgrantbad'] = 'Du mste ange minst en anvndare eller grupp och minst en rttighet.';
 	$lang['strgrantfailed'] = 'Misslyckades att ndra rttigheter.';
 	$lang['stralterprivs'] = 'ndra rttigheter';
 	$lang['strdatabase'] = 'Databas';
@@ -287,13 +287,13 @@
 	$lang['strviewconditions'] = 'Ytterligare villkor';
 
 	// Sequences
-	$lang['strsequence'] = 'Fljd';
-	$lang['strsequences'] = 'Fljder';
-	$lang['strshowallsequences'] = 'Visa alla fljder';
-	$lang['strnosequence'] = 'Hittade ingen fljd.';
-	$lang['strnosequences'] = 'Hittade inga fljder.';
-	$lang['strcreatesequence'] = 'Skapa fljd';
-	$lang['strlastvalue'] = 'Sista vrde';
+	$lang['strsequence'] = 'Sekvens';
+	$lang['strsequences'] = 'Sekvenser';
+	$lang['strshowallsequences'] = 'Visa alla sekvenser';
+	$lang['strnosequence'] = 'Hittade ingen sekvens.';
+	$lang['strnosequences'] = 'Hittade inga sekvenser.';
+	$lang['strcreatesequence'] = 'Skapa sekvens';
+	$lang['strlastvalue'] = 'Senaste vrde';
 	$lang['strincrementby'] = 'ka med';
 	$lang['strstartvalue'] = 'Startvrde';
 	$lang['strmaxvalue'] = 'Strsta vrde';
@@ -301,13 +301,12 @@
 	$lang['strcachevalue'] = 'Vrde p cache';
 	$lang['strlogcount'] = 'Rkna log';
 	$lang['striscycled'] = 'r upprepad?';
-	$lang['striscalled'] = 'r kallad?';
-	$lang['strsequenceneedsname'] = 'Du mste ge ett namn till din fljd.';
-	$lang['strsequencecreated'] = 'Fljd skapad.';
-	$lang['strsequencecreatedbad'] = 'Misslyckades att skapa fljd.'; 
-	$lang['strconfdropsequence'] = 'r du sker p att du vill radera fljden "%s"?';
-	$lang['strsequencedropped'] = 'Fljden borrtagen.';
-	$lang['strsequencedroppedbad'] = 'Misslyckades att radera fljd.';
+	$lang['strsequenceneedsname'] = 'Du mste ge ett namn till din sekvens.';
+	$lang['strsequencecreated'] = 'Sekvens skapad.';
+	$lang['strsequencecreatedbad'] = 'Misslyckades att skapa sekvens.'; 
+	$lang['strconfdropsequence'] = 'r du sker p att du vill radera sekvensen "%s"?';
+	$lang['strsequencedropped'] = 'Sekvensen borrtagen.';
+	$lang['strsequencedroppedbad'] = 'Misslyckades att radera sekvens.';
 
 	// Indexes
 	$lang['strindex'] = 'Index';
@@ -315,8 +314,8 @@
 	$lang['strindexname'] = 'Indexnamn';
 	$lang['strshowallindexes'] = 'Visa alla index';
 	$lang['strnoindex'] = 'Hittade inget index.';
-	$lang['strsequencereset'] = 'Nollstll fljd.';
-	$lang['strsequenceresetbad'] = 'Misslyckades att nollstlla fljd.';
+	$lang['strsequencereset'] = 'Nollstll sekvens.';
+	$lang['strsequenceresetbad'] = 'Misslyckades att nollstlla sekvens.';
 	$lang['strnoindexes'] = 'Hittade inga index.';
 	$lang['strcreateindex'] = 'Skapa index';
 	$lang['strindexname'] = 'Indexnamn';
@@ -467,7 +466,7 @@
 	$lang['strreport'] = 'Rapport';
 	$lang['strreports'] = 'Rapporter';
 	$lang['strshowallreports'] = 'Visa alla rapporter';
-	$lang['strtopbar'] = '%s krs p %s:%s -- Du r inloggad som anvndare "%s", %s';
+	$lang['strtopbar'] = '%s krs p %s:%s -- Du r inloggad som anvndare "%s"';
 	$lang['strtimefmt'] = 'jS M, Y g:iA';
 	$lang['strnoreports'] = 'Hittade inga rapporter.';
 	$lang['strcreatereport'] = 'Skapa rapport';
